import React from 'react';
import classNames from 'classnames/bind';
import styles from './CookieConsentBar.scss';
import Cookies from '../../assets/cookies.svg';

const cx = classNames.bind(styles);

const YEAR100 = 1000 * 60 * 60 * 24 * 365 * 100;

export default class CookieConsentBar extends React.PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      isShow: true,
    };
    this.allowDomains = ['localhost', '.cnyes.cool', '.cnyes.com'];
    this.nowUrl = location.href;
    this.farfuture = new Date(new Date().getTime() + YEAR100); // 設定100y類永久
  }

  componentWillMount() {
    if (document.cookie.includes('consentCookie')) {
      this.setState({ isShow: false });
    }
  }

  handleClickClose = () => {
    this.setState({ isShow: false });
  };

  handleClickConcent = () => {
    this.allowDomains.forEach(domain => {
      if (this.nowUrl.includes(domain)) {
        // localhost 供本地測試用，需不設網域。
        const domainStr = domain === 'localhost' ? '' : `domain:${domain};`;

        document.cookie = `consentCookie=true; ${domainStr} expires=${this.farfuture}`;
      }
    });
    this.setState({ isShow: false });
  };

  render() {
    const { isShow } = this.state;

    if (!isShow) return null;

    return (
      <div className={cx('cookie-bar-container')}>
        <div className={cx('cookie-bar')}>
          <img src={Cookies} alt="cookies" />
          <p>
            為優化網站服務，鉅亨網使用Cookie來改善使用者體驗。當您繼續使用本網站即表示您同意Cookies政策與<a
              href="https://www.cnyes.com/cnyes_about/cnyes_sos04.html"
              target="_blank"
              rel="noopener noreferrer"
            >
              隱私權政策
            </a>。
          </p>
          <button className={cx('consent')} onClick={this.handleClickConcent}>
            繼續使用
          </button>
          <button className={cx('close')} onClick={this.handleClickClose} />
        </div>
      </div>
    );
  }
}
